#Steps to integrate GHUnit into your iOS Project


##Setup


* Create a new "Tests" target within your app by selecting the Project file and clicking "Add Target"
	* Select a new "Window-based Application"
	* Name it something, say "Tests"

* Add GHUnitiOS.framework to your project
	* Right-click on the "Frameworks" folder within your project, and select "Add Files to 'Testable'..."
	* Select GHUnitiOS.framework - make sure only the "Tests" target is selected, and to copy the framework into your project

* Enable Static Library Objective-C Categories
	* In the "Tests" target, select Build Settings
	* Under "Other Linker Flags", add ```-ObjC``` and ```-all_load```

* Enabling GHUnit
	* Select and delete ```TestAppDelegate.h/.m``` and ```MainWindow.xib``` from "Tests" folder within your project - keep the "Supporting Files" folder!
	* In "Supporting Files", select ```Tests-Info.plist``` - you will want to remove the entries for ```Main nib file base name```
	* In "Supporting Files", select ```main.m``` - replace the last argument of ```UIApplicationMain``` with ```@"GHUnitIOSAppDelegate"```


##Running GHUnit

* To run GHUnit, all you need to do is select the "Tests" target for the Active Scheme, and select the iPhone Simulator as the device.
* You should see a an empty table view with the ability to run tests.

**Congrats!  You've setup GHUnit for your project!**

##Creating a Test

_To create a test is simple!_

* Within the "Tests" folder, create a new File
* Select Objective-C class (leave the default subclass of NSObject is fine - for now)
* Name it ```SomethingCoolTest.m``` and **only enable for the "Tests" target**

Next, you'll want to configure your ```.h/.m``` to be GHUnit compatible.

* In the .h, add this line: ```#import <GHUnitIOS/GHUnit.h>```
* Also in the .h, make your test class a subclass of ```GHTestCase``` 

**Now for the test!**

In your .m:

```
- (void)testStrings {       
    NSString *string1 = @"a string";
    GHTestLog(@"I can log to the GHUnit test console: %@", string1);

    // Assert string1 is not NULL, with no custom error description
    GHAssertNotNULL(string1, nil);

    // Assert equal objects, add custom error description
    NSString *string2 = @"a string";
    GHAssertEqualObjects(string1, string2, @"A custom error message. string1 should be equal to: %@.", string2);
  }
```

Make sure you have the _Active Scheme_ with the iPhone Simulator selected and click "Run".  You should see the tests table view with ```testStrings``` test able to run!

**Congrats!  You can now test the shit out of your app with GHUnit!**
